@@ -22,6 +22,7 @@
 #
 #  ============================================================================
 
+import itertools
 import logging
 logger = logging.getLogger('camelot.admin.entity_admin')
 
@@ -245,8 +246,7 @@ It has additional class attributes that customise its behaviour.
 
             try:
                 property = self.mapper.get_property(
-                    field_name,
-                    resolve_synonyms=True
+                    field_name
                 )
                 if isinstance(property, orm.properties.ColumnProperty):
                     column_type = property.columns[0].type
@@ -261,7 +261,7 @@ It has additional class attributes that customise its behaviour.
                         attributes['default'] = property.columns[0].default
                 elif isinstance(property, orm.properties.PropertyLoader):
                     target = forced_attributes.get( 'target', 
-                                                    property._get_target().class_ )
+                                                    property.mapper.class_ )
                     
                     #
                     # _foreign_keys is for sqla pre 0.6.4
@@ -280,7 +280,7 @@ It has additional class attributes that customise its behaviour.
                             delegate = delegates.One2ManyDelegate,
                             target = target,
                             create_inline = False,
-                            direction = property.direction,
+                            direction = 'onetomany',
                             admin = get_entity_admin(target)
                         )
                     elif property.direction == orm.interfaces.MANYTOONE:
@@ -294,7 +294,7 @@ It has additional class attributes that customise its behaviour.
                             # of only the first one
                             #
                             nullable = foreign_keys[0].nullable,
-                            direction = property.direction,
+                            direction = 'manytoone',
                             admin = get_entity_admin(target)
                         )
                     elif property.direction == orm.interfaces.MANYTOMANY:
@@ -304,8 +304,8 @@ It has additional class attributes that customise its behaviour.
                             target = target,
                             nullable = True,
                             create_inline = False,
-                            direction = property.direction,
-                            delegate = delegates.ManyToManyDelegate,
+                            direction = 'manytomany',
+                            delegate = delegates.One2ManyDelegate,
                             admin = get_entity_admin(target)
                         )
                     else:
@@ -342,18 +342,18 @@ It has additional class attributes that customise its behaviour.
 
     def get_dynamic_field_attributes(self, obj, field_names):
         """Takes the dynamic field attributes from through the ObjectAdmin its
-        get_dynamic_field_attributes and add the new_message attributes for
-        One2Many fields where the object was not flushed yet
+        get_dynamic_field_attributes and make relational fields not editable
+        in case the object is not yet persisted.
         """
-        from sqlalchemy.orm.session import Session
-        session = Session.object_session( obj )
-        # when a previous flush failed, obj might have no session
-        if session and obj in session.new:
-            new_message = ugettext('Please complete the form first')
-        else:
-            new_message = None
-        for attributes in super(EntityAdmin, self).get_dynamic_field_attributes(obj, field_names):
-            attributes['new_message'] = new_message
+        directions = ('onetomany', 'manytomany' )
+        persistent = self.is_persistent( obj )
+        iter1, iter2 = itertools.tee( field_names )
+        attributes_iterator = super(EntityAdmin, self).get_dynamic_field_attributes( obj, iter1 )
+        for attributes, field_name in zip( attributes_iterator, iter2 ):
+            if not persistent:
+                all_attributes = self.get_field_attributes( field_name )
+                if all_attributes.get('direction', False) in directions:
+                    attributes['editable'] = False
             yield attributes
             
     @model_function
@@ -361,80 +361,20 @@ It has additional class attributes that customise its behaviour.
         return self.list_charts
 
     @model_function
-    def get_filters(self):
+    def get_filters( self ):
         """Returns the filters applicable for these entities each filter is
 
-        :return: [(filter_name, [(option_name, query_decorator), ...), ... ]
+        :return: [(filter, filter_data)]
         """
         from camelot.view.filters import structure_to_filter
 
         def filter_generator():
             for structure in self.list_filter:
                 filter = structure_to_filter(structure)
-                yield (filter, filter.get_name_and_options(self))
+                yield (filter, filter.get_filter_data(self))
 
         return list(filter_generator())
 
-    @model_function
-    def set_defaults(self, entity_instance, include_nullable_fields=True):
-        """Set the fields of an object to their default state.
-        
-        :param include_nullable_fields: also set defaults for nullable fields, 
-            depending on the context, this should be set to False to allow 
-            the user to set the field to None
-        """
-        from sqlalchemy.schema import ColumnDefault
-        
-        if self.is_deleted( entity_instance ):
-            return False
-
-        for field, attributes in self.get_fields():
-            has_default = False
-            try:
-                default = attributes['default']
-                has_default = True
-            except KeyError:
-                pass
-            if has_default:
-                #
-                # prevent the setting of a default value when one has been
-                # set already
-                #
-                value = attributes['getter'](entity_instance)
-                if value!=None: # False is a legitimate value for Booleans
-                    continue
-                if isinstance(default, ColumnDefault):
-                    default_value = default.execute()
-                elif callable(default):
-                    import inspect
-                    args, _varargs, _kwargs, _defs = \
-                        inspect.getargspec(default)
-                    if len(args):
-                        default_value = default(entity_instance)
-                    else:
-                        default_value = default()
-                else:
-                    default_value = default
-                logger.debug(
-                    'set default for %s to %s' % (
-                        field,
-                        unicode(default_value)
-                    )
-                )
-                try:
-                    setattr(entity_instance, field, default_value)
-                except AttributeError, exc:
-                    logger.error(
-                        'Programming Error : could not set'
-                        ' attribute %s to %s on %s' % (
-                            field,
-                            default_value,
-                            entity_instance.__class__.__name__
-                        ),
-                        exc_info=exc
-                    )
-
-
     @gui_function
     def create_select_view(admin, query=None, search_text=None, parent=None):
         """Returns a Qt widget that can be used to select an element from a
@@ -446,6 +386,7 @@ It has additional class attributes that customise its behaviour.
         returned widget has an entity_selected_signal signal that will be fired
         when a entity has been selected.
         """
+        from camelot.admin.action.base import GuiContext
         from camelot.view.art import Icon
         from camelot.view.proxy.queryproxy import QueryTableProxy
         from PyQt4 import QtCore, QtGui
@@ -459,7 +400,9 @@ It has additional class attributes that customise its behaviour.
             title_format = ugettext('Select %s')
 
             def __init__(self, admin, parent):
+                gui_context = GuiContext()
                 super(SelectView, self).__init__(
+                    gui_context,
                     admin,
                     search_text=search_text, parent=parent
                 )
@@ -502,10 +445,12 @@ It has additional class attributes that customise its behaviour.
         return widget
 
     @gui_function
-    def create_table_view( self ):
-        """Returns a QWidget containing a table view
+    def create_table_view( self, gui_context ):
+        """Returns a :class:`QtGui.QWidget` containing a table view
+        :param gui_context: a :class:`camelot.admin.action.base.GuiContext`
+            object.
         """
-        return self.TableView( self )
+        return self.TableView( gui_context, self )
 
     @model_function
     def delete(self, entity_instance):
@@ -639,7 +584,7 @@ It has additional class attributes that customise its behaviour.
         for property in self.mapper.iterate_properties:
             if isinstance(property, orm.properties.PropertyLoader):
                 if property.direction == orm.interfaces.ONETOMANY:
-                    target = property._get_target().class_
+                    target = property.mapper.class_
                     for relation in serialized.get(property.key, []):
                         relation_mapper = orm.class_mapper(target)
                         for primary_key_field in relation_mapper.primary_key:
