@@ -32,7 +32,6 @@ from currencydelegate import CurrencyDelegate
 from customdelegate import CustomDelegate
 from datedelegate import DateDelegate
 from datetimedelegate import DateTimeDelegate
-from enumerationdelegate import EnumerationDelegate
 from filedelegate import FileDelegate
 from floatdelegate import FloatDelegate
 from imagedelegate import ImageDelegate
@@ -40,7 +39,6 @@ from integerdelegate import IntegerDelegate
 from intervalsdelegate import IntervalsDelegate
 from languagedelegate import LanguageDelegate
 from localfiledelegate import LocalFileDelegate
-from manytomanydelegate import ManyToManyDelegate
 from many2onedelegate import Many2OneDelegate
 from one2manydelegate import One2ManyDelegate
 from manytoonechoicesdelegate import ManyToOneChoicesDelegate
@@ -68,7 +66,6 @@ __all__ = [
     CustomDelegate.__name__,
     DateDelegate.__name__,
     DateTimeDelegate.__name__,
-    EnumerationDelegate.__name__,
     FileDelegate.__name__,
     FloatDelegate.__name__,
     ImageDelegate.__name__,
@@ -76,7 +73,6 @@ __all__ = [
     IntervalsDelegate.__name__,
     LanguageDelegate.__name__,
     LocalFileDelegate.__name__,
-    ManyToManyDelegate.__name__,
     Many2OneDelegate.__name__,
     One2ManyDelegate.__name__,
     ManyToOneChoicesDelegate.__name__,
