@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -24,20 +24,17 @@
 from PyQt4 import QtGui
 from PyQt4.QtCore import Qt
 
-from customdelegate import DocumentationMetaclass
+from customdelegate import DocumentationMetaclass, CustomDelegate
 from camelot.core.utils import variant_to_pyobject
 from camelot.view.proxy import ValueLoading
 
-class IntervalsDelegate(QtGui.QItemDelegate):
+class IntervalsDelegate(CustomDelegate):
     """Custom delegate for visualizing camelot.container.IntervalsContainer
-  data
+  data:
   """
   
     __metaclass__ = DocumentationMetaclass
-  
-    def __init__(self, parent=None, **kwargs):
-        QtGui.QItemDelegate.__init__(self, parent)
-    
+      
     def paint(self, painter, option, index):
         painter.save()
         self.drawBackground(painter, option, index)
@@ -66,7 +63,8 @@ class IntervalsDelegate(QtGui.QItemDelegate):
             xoffset = intervals_container.min * xscale + rect.x()
             yoffset = rect.y() + rect.height()/2
             for interval in intervals_container.intervals:
-                pen = QtGui.QPen(color or interval.color)
+                qcolor = QtGui.QColor( interval.color or color )
+                pen = QtGui.QPen( qcolor )
                 pen.setWidth(3)
                 painter.setPen(pen)
                 xscale_interval = xscale
@@ -87,3 +85,4 @@ class IntervalsDelegate(QtGui.QItemDelegate):
     def setModelData(self, editor, model, index):
         pass
 
+
