@@ -33,7 +33,7 @@ logger = logging.getLogger( 'camelot.view.controls.delegates.one2manydelegate' )
 class One2ManyDelegate( CustomDelegate ):
     """Custom delegate for many 2 one relations
   
-  .. image:: /_static/onetomany.png  
+  .. image:: /_static/onetomany.png
   """
 
     __metaclass__ = DocumentationMetaclass
@@ -47,6 +47,7 @@ class One2ManyDelegate( CustomDelegate ):
         logger.debug( 'create a one2many editor' )
         editor = editors.One2ManyEditor( parent = parent, **self.kwargs )
         self.setEditorData( editor, index )
+        editor.editingFinished.connect( self.commitAndCloseEditor )
         return editor
 
     def setEditorData( self, editor, index ):
@@ -58,8 +59,3 @@ class One2ManyDelegate( CustomDelegate ):
 
     def setModelData( self, editor, model, index ):
         pass
-    
-    def render_ooxml( self, value ):
-        return []
-
-
