@@ -47,16 +47,17 @@ class ChartEditor(QtGui.QFrame, CustomEditor, WideEditor):
     show_fullscreen_signal = QtCore.pyqtSignal()
     editingFinished = QtCore.pyqtSignal()
 
-    def __init__(self, parent=None, width=50, height=40, dpi=50, **kwargs):
+    def __init__(self, parent=None, width=50, height=40, dpi=50, field_name='chart', **kwargs):
         from matplotlib.figure import Figure
         from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
         super(ChartEditor, self).__init__(parent)
+        self.setObjectName( field_name )
         
         chart_frame = QtGui.QFrame( self )
         chart_frame.setFrameShape( self.Box )
         chart_frame.setContentsMargins( 1, 1, 1, 1 )
         chart_frame_layout = QtGui.QHBoxLayout()
-        chart_frame_layout.setMargin(0)
+        chart_frame_layout.setContentsMargins( 0, 0, 0, 0)
         chart_frame.setLayout( chart_frame_layout )
 
         # find out background color, because using a transparent
@@ -95,7 +96,7 @@ class ChartEditor(QtGui.QFrame, CustomEditor, WideEditor):
         button_layout.addWidget( copy_button )
                 
         layout.addLayout( button_layout )
-        layout.setMargin(0)
+        layout.setContentsMargins( 0, 0, 0, 0)
         self.setLayout(layout)
         self.canvas.setSizePolicy(
             QtGui.QSizePolicy.Expanding,
