@@ -55,8 +55,11 @@ to display a progress dialog until my_function has finished::
         #label.setPixmap(icon.getQPixmap())
         self.setLabel( label )
         self.setWindowTitle( _('Please wait') )
-        self.setMinimumDuration( 1 )
-
+        # show immediately, to prevent a pop up before another window
+        # opened in an action_step
+        self.show() 
+        #QtCore.QTimer.singleShot( 1000, self.show )
+            
     @QtCore.pyqtSlot(bool)
     @QtCore.pyqtSlot()
     def finished(self, success=True):
@@ -68,22 +71,6 @@ to display a progress dialog until my_function has finished::
         model_thread_exception_message_box(exception_info)
         self.finished(False)
         
-    @QtCore.pyqtSlot(object)
-    def display_chart(self, chart ):
-        from camelot.view.controls.editors import ChartEditor
-        litebox = ChartEditor.show_fullscreen_chart(chart, self)
-        litebox.closed_signal.connect( self.close )
-
-    @QtCore.pyqtSlot(object)
-    def display_pixmap(self, pixmap):
-        """
-        :param image: a camelot.view.art.Pixmap object
-        """
-        from camelot.view.controls.liteboxview import LiteBoxView
-        litebox = LiteBoxView(parent=self)
-        litebox.closed_signal.connect( self.close )
-        litebox.show_fullscreen_pixmap( pixmap.getQPixmap() )
-        
     @QtCore.pyqtSlot(object)
     def exit(self, return_code):
         """Stop the application event loop, with the given return code"""
