@@ -24,7 +24,6 @@
 
 """Tableview"""
 
-import functools
 import logging
 logger = logging.getLogger( 'camelot.view.controls.tableview' )
 
@@ -375,10 +374,12 @@ class HeaderWidget( QtGui.QWidget ):
         from camelot.view.controls.filter_operator import FilterOperator
         layout = QtGui.QHBoxLayout()
         layout.setSpacing( 2 )
+        layout.setContentsMargins( 0, 0, 0, 0 )
         for i, (field, attributes) in enumerate(columns):
             if 'operators' in attributes and attributes['operators']:
                 box = QtGui.QGroupBox()
                 box_layout = QtGui.QVBoxLayout()
+                box_layout.setContentsMargins( 1, 1, 1, 1 )
                 widget = FilterOperator( self._admin.entity,
                                          field, attributes,
                                          box )
@@ -440,7 +441,14 @@ class Splitter(QtGui.QSplitter):
         return SplitterHandle( self.orientation(), self, self._widget_to_hide )
     
 class TableView( AbstractView  ):
-    """A generic tableview widget that puts together some other widgets.  The behaviour of this class and
+    """
+  :param gui_context: a :class:`camelot.admin.action.application_action.ApplicationActionGuiContext`
+      object.
+  :param admin: an :class:`camelot.admin.entity_admin.EntityAdmin` object
+  :param search_text: a predefined search text to put in the search widget
+  :param parent: a :class:`QtGui.QWidget` object
+  
+  A generic tableview widget that puts together some other widgets.  The behaviour of this class and
   the resulting interface can be tuned by specifying specific class attributes which define the underlying
   widgets used ::
 
@@ -490,9 +498,15 @@ class TableView( AbstractView  ):
 
     row_selected_signal = QtCore.pyqtSignal(int)
 
-    def __init__( self, admin, search_text = None, parent = None ):
+    def __init__( self, 
+                  gui_context, 
+                  admin, 
+                  search_text = None, 
+                  parent = None ):
         super(TableView, self).__init__( parent )
         self.admin = admin
+        self.application_gui_context = gui_context
+        self.gui_context = gui_context
         post( self.get_title, self.change_title )
         widget_layout = QtGui.QVBoxLayout()
         if self.header_widget:
@@ -564,16 +578,6 @@ class TableView( AbstractView  ):
         """emits a row_selected signal"""
         self.admin.list_action.gui_run( self.gui_context )
 
-    def copy_selected_rows( self ):
-        """Copy the selected rows in this tableview"""
-        logger.debug( 'delete selected rows called' )
-        if self.table and self.table.model():
-            for row in set( map( lambda x: x.row(), self.table.selectedIndexes() ) ):
-                self.table.model().copy_row( row )
-
-    def select_all_rows( self ):
-        self.table.selectAll()
-
     def create_table_model( self, admin ):
         """Create a table model for the given admin interface"""
         return self.table_model( admin,
@@ -608,7 +612,8 @@ class TableView( AbstractView  ):
         self.table.model().layoutChanged.connect( self.tableLayoutChanged )
         self.tableLayoutChanged()
         self.table_layout.insertWidget( 1, self.table )
-        self.gui_context = ListActionGuiContext()
+        self.gui_context = self.application_gui_context.copy( ListActionGuiContext )
+        self.gui_context.view = self
         self.gui_context.admin = self.admin
         self.gui_context.item_view = self.table
 
@@ -634,18 +639,6 @@ class TableView( AbstractView  ):
         for i in range( model.columnCount() ):
             self.table.setColumnWidth( i, model.headerData( i, Qt.Horizontal, Qt.SizeHintRole ).toSize().width() )
 
-    def deleteSelectedRows( self ):
-        """delete the selected rows in this tableview"""
-        self.table.delete_selected_rows()
-
-    @gui_function
-    def newRow( self ):
-        """Create a new row in the tableview"""
-        from camelot.view.workspace import show_top_level
-        form = self.admin.create_new_view( related_collection_proxy=self.get_model(),
-                                           parent = None )
-        show_top_level( form, self )
-
     def closeEvent( self, event ):
         """reimplements close event"""
         logger.debug( 'tableview closed' )
@@ -655,61 +648,14 @@ class TableView( AbstractView  ):
         """selects the specified row"""
         self.table.selectRow( row )
 
-    def makeImport(self):
-        pass
-#        for row in data:
-#            o = self.admin.entity()
-#            #For example, setattr(x, 'foobar', 123) is equivalent to x.foobar = 123
-#            # if you want to import all attributes, you must link them to other objects
-#            #for example: a movie has a director, this isn't a primitive like a string
-#            # but a object fetched from the db
-#            setattr(o, object_attributes[0], row[0])
-#            name = row[2].split( ' ' ) #director
-#            o.short_description = "korte beschrijving"
-#            o.genre = ""
-#            from sqlalchemy.orm.session import Session
-#            Session.object_session(o).flush([o])
-#
-#    post( makeImport )
-
-    @gui_function
-    def selectedTableIndexes( self ):
-        """returns a list of selected rows indexes"""
-        return self.table.selectedIndexes()
-
     def getColumns( self ):
         """return the columns to be displayed in the table view"""
         return self.admin.get_columns()
 
-    def getData( self ):
-        """generator for data queried by table model"""
-        for d in self.table.model().getData():
-            yield d
-
     def getTitle( self ):
         """return the name of the entity managed by the admin attribute"""
         return self.admin.get_verbose_name()
 
-    def viewFirst( self ):
-        """selects first row"""
-        self.selectTableRow( 0 )
-
-    def viewLast( self ):
-        """selects last row"""
-        self.selectTableRow( self.table.model().rowCount() - 1 )
-
-    def viewNext( self ):
-        """selects next row"""
-        first = self.selectedTableIndexes()[0]
-        next = ( first.row() + 1 ) % self.table.model().rowCount()
-        self.selectTableRow( next )
-
-    def viewPrevious( self ):
-        """selects previous row"""
-        first = self.selectedTableIndexes()[0]
-        prev = ( first.row() - 1 ) % self.table.model().rowCount()
-        self.selectTableRow( prev )
-
     @QtCore.pyqtSlot(object)
     def _set_query(self, query_getter):
         if isinstance(self.table.model(), QueryTableProxy):
@@ -756,31 +702,6 @@ class TableView( AbstractView  ):
         self.search_filter = lambda q: q
         self.rebuild_query()
 
-    @gui_function
-    def get_selection_getter(self):
-        """:return: a function that when called return an iterable with all the 
-        objects corresponding to the selected rows in the table."""
-        selected_rows = set( map( lambda x: x.row(), self.table.selectedIndexes() ) )
-        
-        def selection_getter(table, selected_rows):
-            selection = []
-            model = table.model()
-            for row in selected_rows:
-                selection.append( model._get_object(row) )
-            return selection
-        
-        return functools.partial( selection_getter, self.table, selected_rows )
-
-    @gui_function
-    def get_collection_getter(self):
-        """:return: a list with all the objects corresponding to the rows in the table
-        """
-        
-        def get_collection(table):
-            return table.model().get_collection()
-        
-        return functools.partial( get_collection, self.table )
-
     @QtCore.pyqtSlot(object)
     @gui_function
     def set_filters_and_actions( self, filters_and_actions ):
@@ -815,30 +736,6 @@ class TableView( AbstractView  ):
             actions_widget.set_actions( actions )
             self.filters_layout.addWidget( actions_widget )
 
-    def to_html( self ):
-        """generates html of the table"""
-        if self.table and self.table.model():
-            query_getter = self.table.model().get_query_getter()
-            table = [[getattr( row, col[0] ) for col in self.admin.get_columns()]
-                     for row in query_getter().all()]
-            context = {
-              'title': self.admin.get_verbose_name_plural(),
-              'table': table,
-              'columns': [field_attributes['name'] for _field, field_attributes in self.admin.get_columns()],
-            }
-            from camelot.view.templates import loader
-            from jinja2 import Environment
-            env = Environment( loader = loader )
-            tp = env.get_template( 'table_view.html' )
-            return tp.render( context )
-
-    def importFromFile( self ):
-        """"import data : the data will be imported in the activeMdiChild """
-        logger.info( 'call import method' )
-        from camelot.view.wizard.importwizard import ImportWizard
-        wizard = ImportWizard(self, self.admin)
-        wizard.exec_()
-
     @QtCore.pyqtSlot()
     def focusTable(self):
         if self.table and self.table.model().rowCount() > 0:
