@@ -28,8 +28,6 @@ from PyQt4 import QtGui
 from PyQt4 import QtCore
 
 from camelot.view.model_thread import post
-from camelot.view.model_thread import model_function
-
 
 class AbstractView(QtGui.QWidget):
     """A string used to format the title of the view ::
@@ -64,30 +62,6 @@ class AbstractView(QtGui.QWidget):
     def change_icon(self, new_icon):
         self.icon_changed_signal.emit(new_icon)
 
-    @model_function
-    def to_html(self):
-        pass
-
-    @model_function
-    def export_to_word(self):
-        from camelot.view.export.word import open_html_in_word
-        html = self.to_html()
-        open_html_in_word(html)
-
-    @model_function
-    def export_to_excel(self):
-        from camelot.view.export.excel import open_data_with_excel
-        title = self.getTitle()
-        columns = self.getColumns()
-        data = [d for d in self.getData()]
-        open_data_with_excel(title, columns, data)
-
-    @model_function
-    def export_to_mail(self):
-        from camelot.view.export.outlook import open_html_in_outlook
-        html = self.to_html()
-        open_html_in_outlook(html)
-
 class TabView(AbstractView):
     """Class to combine multiple views in Tabs and let them behave as one view.
     This class can be used when defining custom create_table_view methods on an
@@ -123,17 +97,3 @@ class TabView(AbstractView):
     def set_views_and_titles(self, views_and_titles):
         for view, title in views_and_titles:
             self._tab_widget.addTab(view, title)
-
-    def export_to_excel(self):
-        return self._tab_widget.currentWidget().export_to_excel()
-
-    def export_to_word(self):
-        return self._tab_widget.currentWidget().export_to_word()
-
-    def export_to_mail(self):
-        return self._tab_widget.currentWidget().export_to_mail()
-
-    def to_html(self):
-        return self._tab_widget.currentWidget().to_html()
-
-
