@@ -27,9 +27,12 @@ import sys
 import logging
 import pkgutil
 
+# from collections import defaultdict
+
 from sqlalchemy import create_engine
 
 from PyQt4 import QtCore
+from PyQt4 import QtNetwork
 from PyQt4.QtCore import Qt
 from PyQt4.QtCore import QFileInfo
 from PyQt4.QtGui import QBoxLayout, QDialog, QFont, QGridLayout, QHBoxLayout, \
@@ -40,10 +43,12 @@ from camelot.view.controls.editors import ChoicesEditor, TextLineEditor, Languag
 from camelot.view.controls.standalone_wizard_page import HSeparator, StandaloneWizardPage
 from camelot.view.controls.combobox_input_dialog import ComboBoxInputDialog
 
+from camelot.core.exception import UserException
 from camelot.core.utils import ugettext as _
 from camelot.view.model_thread.signal_slot_model_thread import SignalSlotModelThread
+from camelot.view.model_thread import gui_function
 from camelot.core.dbprofiles import fetch_profiles, use_chosen_profile, \
-    store_profiles, get_network_proxy, check_connection, last_used_profile
+    store_profiles, get_network_proxy, last_used_profile
 
 logger = logging.getLogger('camelot.view.database_selection')
 
@@ -111,17 +116,20 @@ class ProfileWizard(StandaloneWizardPage):
 profile.
 
 .. attribute:: languages
+.. attribute:: dialects
 
 A list of languages allowed in the profile selection, an empty list will
 allow all languages
     """
 
     languages = []
+    dialects = []
 
     def __init__(self, profiles, parent=None):
         super(ProfileWizard, self).__init__(parent)
 
         self._connection_valid = False
+        self.network_reply = None
         self.profiles = profiles
 
         self.setWindowTitle(_('Profile Wizard'))
@@ -130,18 +138,27 @@ allow all languages
         self.set_banner_subtitle(_('Please enter the database settings'))
         self.banner_widget().setStyleSheet('background-color: white;')
 
+        self.manager = QtNetwork.QNetworkAccessManager( self )
+        self.manager.finished.connect( self.update_network_status )
+        #self.manager.networkAccessibleChanged.connect( self.network_accessible_changed )
+        self.manager.proxyAuthenticationRequired.connect( self.proxy_authentication_required )
+        
         self.create_labels_and_widgets()
         self.create_buttons()
-
         self.set_tab_order()
-
         self.set_widgets_values()
-
         # note: connections come after labels and widgets are created
         # and have default values
         self.connect_widgets()
         self.connect_buttons()
+        
+        timer = QtCore.QTimer(self)
+        timer.timeout.connect( self.new_network_request )
+        timer.setInterval( 3000 )
+        timer.start()
+        self.new_network_request()
 
+    @gui_function
     def create_labels_and_widgets(self):
         self.profile_label = QLabel(_('Profile Name:'))
         self.dialect_label = QLabel(_('Driver:'))
@@ -156,12 +173,7 @@ allow all languages
         self.proxy_port_label = QLabel(_('Port:'))
         self.proxy_username_label = QLabel(_('Proxy Username:'))
         self.proxy_password_label = QLabel(_('Proxy Password:'))
-
-        self.working_proxy_label = QLabel(_('Internet available.'))
-        self.working_proxy_label.setStyleSheet('color: green')
-
-        self.not_working_proxy_label = QLabel(_('Internet not available.'))
-        self.not_working_proxy_label.setStyleSheet('color: red')
+        self.network_status_label = QLabel()
 
         self.not_accessible_media_path_label = QLabel(_('Media location path '\
             'is not accessible.'))
@@ -237,16 +249,22 @@ allow all languages
         layout.addWidget(self.proxy_port_editor, 10, 4, 1, 1)
         layout.addWidget(self.proxy_username_editor, 11, 1, 1, 1)
         layout.addWidget(self.proxy_password_editor, 12, 1, 1, 1)
-
+        
+        layout.addWidget(self.network_status_label, 13, 1, 1, 4)
+        
         self.main_widget().setLayout(layout)
 
     def set_widgets_values(self):
         self.dialect_editor.clear()
         self.profile_editor.clear()
-
-        import sqlalchemy.dialects
-        dialects = [name for _importer, name, is_package in \
-            pkgutil.iter_modules(sqlalchemy.dialects.__path__) if is_package]
+        
+        if self.dialects:
+            dialects = self.dialects
+        else:
+            import sqlalchemy.dialects
+            dialects = [name for _importer, name, is_package in \
+                        pkgutil.iter_modules(sqlalchemy.dialects.__path__) \
+                        if is_package]
         self.dialect_editor.set_choices([(dialect, dialect.capitalize()) \
             for dialect in dialects])
 
@@ -257,29 +275,19 @@ allow all languages
 
     def connect_widgets(self):
         self.profile_editor.editTextChanged.connect(self.update_wizard_values)
-
-        #self.proxy_host_editor.textChanged.connect(lambda text: \
-        #    self.update_proxy_values())
-        #self.proxy_port_editor.textChanged.connect(lambda text: \
-        #    self.update_proxy_values())
-        #self.proxy_username_editor.textChanged.connect(lambda text: \
-        #    self.update_proxy_values())
-        #self.proxy_password_editor.textChanged.connect(lambda text: \
-        #    self.update_proxy_values())
-
+        # self.dialect_editor.currentIndexChanged.connect(self.update_wizard_values)    
+    
     def create_buttons(self):
         self.more_button = QPushButton(_('More'))
         self.more_button.setCheckable(True)
         self.more_button.setAutoDefault(False)
         self.cancel_button = QPushButton(_('Cancel'))
-        #self.clear_button = QPushButton(_('Clear'))
         self.ok_button = QPushButton(_('OK'))
 
         layout = QHBoxLayout()
         layout.setDirection(QBoxLayout.RightToLeft)
 
         layout.addWidget(self.cancel_button)
-        #layout.addWidget(self.clear_button)
         layout.addWidget(self.ok_button)
         layout.addStretch()
         layout.addWidget(self.more_button)
@@ -298,13 +306,13 @@ allow all languages
         self.save_button = QPushButton(_('Save profiles'))
 
         extension_buttons_layout = QHBoxLayout()
-        extension_buttons_layout.setMargin(0)
+        extension_buttons_layout.setContentsMargins(0, 0, 0, 0)
         extension_buttons_layout.addWidget(self.load_button)
         extension_buttons_layout.addWidget(self.save_button)
         extension_buttons_layout.addStretch()
 
         extension_layout = QVBoxLayout()
-        extension_layout.setMargin(0)
+        extension_layout.setContentsMargins(0, 0, 0, 0)
         extension_layout.addWidget(HSeparator())
         extension_layout.addLayout(extension_buttons_layout)
 
@@ -330,22 +338,11 @@ allow all languages
     def connect_buttons(self):
         self.cancel_button.pressed.connect(self.reject)
         self.ok_button.pressed.connect(self.proceed)
-        #self.clear_button.pressed.connect(self.clear_fields)
-
         self.browse_button.pressed.connect(self.fill_media_location)
-
         self.more_button.toggled.connect(self.extension.setVisible)
-
         self.save_button.pressed.connect(self.save_profiles_to_file)
         self.load_button.pressed.connect(self.load_profiles_from_file)
 
-    #def clear_fields(self):
-    #    self.host_editor.clear()
-    #    self.port_editor.clear()
-    #    self.database_name_editor.clear()
-    #    self.username_editor.clear()
-    #    self.password_editor.clear()
-
     def proceed(self):
         if self.is_connection_valid():
             profilename, info = self.collect_info()
@@ -363,20 +360,26 @@ allow all languages
         mt.start()
         progress = ProgressDialog(_('Verifying database settings'))
         mt.post(lambda:self.test_connection(info['dialect'], info['host'],
-            info['user'], info['pass'], info['database']),
+            info['port'], info['user'], info['pass'], info['database']),
             progress.finished, progress.exception)
         progress.exec_()
         return self._connection_valid
 
-    def test_connection(self, dialect, host, user, passwd, db):
+    def test_connection(self, dialect, host, port, user, passwd, db):
         self._connection_valid = False
-        connection_string = '%s://%s:%s@%s/%s' % (dialect, user, passwd, host, db)
+        connection_string = '%s://%s:%s@%s:%s/%s' % (dialect, user, passwd, host, port, db)
         engine = create_engine(connection_string, pool_recycle=True)
-        connection = engine.raw_connection()
-        cursor = connection.cursor()
-        cursor.close()
-        connection.close()
-        self._connection_valid = True
+        try:
+            connection = engine.raw_connection()
+            cursor = connection.cursor()
+            cursor.close()
+            connection.close()
+            self._connection_valid = True
+        except Exception, e:
+            self._connection_valid = False
+            raise UserException( _('Could not connect to database, please check host and port'),
+                                 resolution = _('Verify driver, host and port or contact your system administrator'),
+                                 detail = unicode(e) )
 
     def toggle_ok_button(self, enabled):
         self.ok_button.setEnabled(enabled)
@@ -385,32 +388,65 @@ allow all languages
         text = unicode(self.profile_editor.currentText())
         self.toggle_ok_button(bool(text))
         return text
-
+    
+    # FIXME can't get this to work properly (call in update_wizard_values(): port_editor )
+    # def _related_default_port(self, dialect_editor):
+    #     class Missing(defaultdict):
+    #         def __missing__(self, key):
+    #             return ''
+    #     ports = Missing(mysql='3306', postgresql='5432')
+    #     return ports[dialect_editor.get_value()]
+    
     def update_wizard_values(self):
-        self.dialect_editor.set_value(self.get_profile_value('dialect') or 'mysql')
-        self.host_editor.setText(self.get_profile_value('host') or '127.0.0.1')
-        self.port_editor.setText(self.get_profile_value('port') or '3306')
+        network_proxy = get_network_proxy()
+        # self.dialect_editor.set_value(self.get_profile_value('dialect') or 'mysql')
+        # self.host_editor.setText(self.get_profile_value('host') or '127.0.0.1')
+        # self.port_editor.setText(self.get_profile_value('port') or '3306')        
+        self.dialect_editor.set_value(self.get_profile_value('dialect') or 'postgresql')
+        self.host_editor.setText(self.get_profile_value('host') or self.host_editor.text())
+        self.port_editor.setText(self.get_profile_value('port') or self.port_editor.text())        
+        # self.port_editor.setText(self.get_profile_value('port') or self._related_default_port(self.dialect_editor))
         self.database_name_editor.setText(self.get_profile_value('database') or self.database_name_editor.text())
         self.username_editor.setText(self.get_profile_value('user') or self.username_editor.text())
         self.password_editor.setText(self.get_profile_value('pass') or self.password_editor.text())
         self.media_location_editor.setText(self.get_profile_value('media_location') or self.media_location_editor.text())
         self.language_editor.set_value(self.get_profile_value('locale_language') or self.language_editor.get_value())
-
-        self.update_proxy_values()
-
-    def update_proxy_values(self):
-        network_proxy = get_network_proxy()
         self.proxy_host_editor.setText(self.get_profile_value('proxy_host') or str(network_proxy.hostName()))
         self.proxy_port_editor.setText(self.get_profile_value('proxy_port') or str(network_proxy.port()))
         self.proxy_username_editor.setText(self.get_profile_value('proxy_username') or str(network_proxy.user()))
         self.proxy_password_editor.setText(self.get_profile_value('proxy_password') or str(network_proxy.password()))
+        self.network_status_label.setText('')
+        self.network_status_label.setStyleSheet('')
+        
+    @QtCore.pyqtSlot(QtNetwork.QNetworkProxy, QtNetwork.QAuthenticator)
+    def proxy_authentication_required(self, proxy, authenticator):
+        pass
 
-        if check_connection(proxy=network_proxy):
-            self.main_widget().layout().addWidget(
-                self.working_proxy_label, 13, 1, 1, 4)
+    @QtCore.pyqtSlot(QtNetwork.QNetworkReply)
+    def update_network_status(self, reply):
+        if reply.isFinished():
+            error = reply.error()
+            if error == QtNetwork.QNetworkReply.NoError:
+                self.network_status_label.setText(_('Internet available.'))
+                self.network_status_label.setStyleSheet('color: green')
+                return
+        self.network_status_label.setText(_('Internet not available.\n%s.'%reply.errorString()))
+        self.network_status_label.setStyleSheet('color: red')
+                
+    @QtCore.pyqtSlot()
+    def new_network_request(self):
+        if self.network_reply and not self.network_reply.isFinished():
+            self.network_reply.abort()
+        if self.proxy_host_editor.text():
+            proxy = QtNetwork.QNetworkProxy( QtNetwork.QNetworkProxy.HttpProxy, 
+                                             self.proxy_host_editor.text(), 
+                                             int( str( self.proxy_port_editor.text() ) ) )#,
+                                             #self.proxy_username_editor.text(),
+                                             #self.proxy_password_editor.text() )
+            self.manager.setProxy( proxy )
         else:
-            self.main_widget().layout().addWidget(
-                self.not_working_proxy_label, 13, 1, 1, 4)
+            self.manager.setProxy( QtNetwork.QNetworkProxy() )
+        self.network_reply = self.manager.get( QtNetwork.QNetworkRequest( QtCore.QUrl('http://aws.amazon.com') ) )
 
     def get_profile_value(self, key):
         current = self.current_profile()
@@ -460,37 +496,19 @@ allow all languages
         caption = _('Save Profiles To a File')
         filters = _('Profiles file (*.ini)')
         path = QFileDialog.getSaveFileName(self, caption, 'profiles', filters)
-
         if not path:
+            logger.debug('Could not save profiles to file; no path.')
             return
-
         store_profiles(self.profiles, to_file=path)
 
-        #mt = SignalSlotModelThread(lambda:None)
-        #mt.start()
-        #progress = ProgressDialog(_('Saving progiles to file'))
-        #mt.post(lambda:store_profiles(self.profiles, to_file=path),
-        #    progress.finished, progress.exception)
-        #progress.exec_()
-
     def load_profiles_from_file(self):
         caption = _('Load Profiles From a File')
         filters = _('Profiles file (*.ini)')
         path = QFileDialog.getOpenFileName(self, caption, 'profiles', filters)
-
         if not path:
+            logger.debug('Could not load profiles from file; no path.')
             return
-
         self.profiles = fetch_profiles(from_file=path)
-
-        #mt = SignalSlotModelThread(lambda:None)
-        #mt.start()
-        #progress = ProgressDialog(_('Loading profiles from file'))
-        #mt.post(lambda:setattr(self, 'profiles',
-        #    fetch_profiles(from_file=path)), progress.finished,
-        #    progress.exception)
-        #progress.exec_()
-
         if self.profiles:
             store_profiles(self.profiles)
             os.execv(sys.executable, [sys.executable] + sys.argv)
