@@ -72,6 +72,12 @@ class Task(QtCore.QObject):
             sys.exc_clear()
         except:
             logger.error( 'unhandled exception in model thread' )
+            exc_info = ( 'Unhandled exception', 
+                         sys.exc_info()[0], 
+                         None, 
+                         'Please contact the application developer', '')
+            # still emit the exception signal, to allow the gui to clean up things (such as closing dialogs)
+            self.exception.emit( exc_info )
             sys.exc_clear()
 
 class TaskHandler(QtCore.QObject):
@@ -225,13 +231,3 @@ class SignalSlotModelThread( AbstractModelThread ):
         app = QtCore.QCoreApplication.instance()
         while self.busy():
             app.processEvents()
-
-#    app = QCoreApplication.instance()
-#    waiting = True
-#    while waiting:
-#      waiting = False
-#      if app.hasPendingEvents():
-#        app.processEvents()
-#        waiting = True
-
-
