@@ -39,7 +39,7 @@ class QueryTableProxy(CollectionProxy):
     """
 
     def __init__(self, admin, query_getter, columns_getter,
-                 max_number_of_rows=10, edits=None,
+                 max_number_of_rows=10,
                  cache_collection_proxy=None):
         """@param query_getter: a model_thread function that returns a query, can be None at construction time and set later"""
         logger.debug('initialize query table')
@@ -52,7 +52,6 @@ class QueryTableProxy(CollectionProxy):
         super(QueryTableProxy, self).__init__(admin, lambda: [],
                                               columns_getter, 
                                               max_number_of_rows=max_number_of_rows, 
-                                              edits=None,
                                               cache_collection_proxy=cache_collection_proxy)     
         
     def get_query_getter(self):
@@ -140,7 +139,6 @@ class QueryTableProxy(CollectionProxy):
             try:
                 property = mapper.get_property(
                     field_name,
-                    resolve_synonyms=True
                 )
             except InvalidRequestError:
                 #
@@ -153,7 +151,7 @@ class QueryTableProxy(CollectionProxy):
             #  If it specifies an order_by option we have to join the related table, 
             #  else we use the foreing key as sort field, without joining
             if property and isinstance(property, orm.properties.PropertyLoader):
-                target = property._get_target()
+                target = property.mapper
                 if target:
                     if target.order_by:
                         join = field_name
@@ -229,7 +227,35 @@ class QueryTableProxy(CollectionProxy):
         :return: an iterator over the objects in the collection, starting at 
         offset, until limit
         """
+        from sqlalchemy import orm
+        from sqlalchemy.exc import InvalidRequestError
+        
         query = self.get_query_getter()().offset(offset).limit(limit)
+        #
+        # undefer all columns displayed in the list, to reduce the number
+        # of queries
+        #
+        columns_to_undefer = []
+        for field_name, _field_attributes in self.getColumns():
+            
+            property = None
+            try:
+                property = self.admin.mapper.get_property(
+                    field_name,
+                )
+            except InvalidRequestError:
+                #
+                # If the field name is not a property of the mapper
+                #
+                pass
+
+            if property and isinstance(property, orm.properties.ColumnProperty):
+                columns_to_undefer.append( field_name )
+                
+        if columns_to_undefer:
+            options = [ orm.undefer( field_name ) for field_name in columns_to_undefer ]
+            query = query.options( *options )
+                
         return query.all()
                     
     @model_function
@@ -249,7 +275,7 @@ class QueryTableProxy(CollectionProxy):
                 # since the previous query.
                 #
                 rows_in_cache = 0
-                for row in range(offset, limit + 1):
+                for row in range(offset, offset + limit):
                     try:
                         cached_obj =  self.edit_cache.get_entity_at_row(row)                        
                         self._add_data( columns, row, cached_obj)
